"""
Automated Kinematic GPS Processing with Track from GAMIT/GLOBK
-------------------------------------------------------------------------------------------------------

This package has the following modules:

   variables               - define the variables and setting for the processing
   rinexconverter          - convert raw leica data from Leica GPS500 System
                             Receivers w/ Antennas and convert it to daily kinematic
                             RINEXfiles using TEQC
   kinematicprocessing     - estimation of positions by using TRACK from GLOBK/GAMIT
                             with download of precise ephemeris from a database


To start:

    1) Copy your (single or multiple) Leica binary MDB data folders from each rover
       (mostly they are called foo/GEODB/) into folders named after the rover site name,
       e.g., foo. Do this for any number of moving sites you have, so that you
       have folders as
         bar/foo1,
         bar/foo2,
         bar/foo3,
         etc.
       (-------- *** Note: the sites can only have 4 characters *** -------------)
       
    2) Then, specify the variable site_names to point to the list of directories,
       i.e.,
       ['foo1','foo2','foo3',..]

    3) Set the variable prefix_dir to point to a location where you have enough space and
       write access, e.g., /scratch/otherbar

    4) Call init_workspace() to set up the processing environment.

    5) Call search_rawdata('foo') to search the folders foo/gps.. for the Leica MDB files,
       which will then be copied to prefix_dir/raw/..
       (e.g., in this case
              /scratch/bar/raw/foo1,
              /scratch/bar/raw/foo2,
              and so on.)

    6) Continue with rinex conversion and kinematic processing
       (a call to process() on each of the modules suffices when everything is
       supposed to work nicely) ...

-------------------------------------------------------------------------------------------------------
*** Important *** :

    You need to have the following software installed and added to your 
    PATH variable, to be able to run these modules:

    -TEQC from UNAVCO:

       http://facility.unavco.org/software/teqc/teqc.html
       
    -GAMIT/GLOBL from MIT
    
       http://www-gpsg.mit.edu/~simon/gtgk/index.htm
       
       You actually don't need the full installation. It is sufficient to have 
       the shell-scripts named track, doy, sh_get_orbits, sh_get_ftp_info and
       eventually sh_sp3fit working correctly.

    -Python Module Processing

       http://pypi.python.org/pypi/processing

    
    Patrick Riesen, 2010
-------------------------------------------------------------------------------------------------------

"""
__author__    = "Patrick Riesen (riesen@vaw.baug.ethz.ch)"
__date__      = "2010-07-01"
__copyright__ = "Copyright (C) 2010 Patrick Riesen"
__license__   = "GNU GPL version 3 or any later version"


# Import the relevant things
from kingps.variables import execute, GPSProcessingVariables
from kingps.rinexconverter import GPSToRinexConverter
from kingps.kinematicprocessing import GPSKinematicProcessing

